==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/track/MoveTrackDownAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.track;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.track.UndoableMoveTrackDown;
import org.herac.tuxguitar.song.models.SongTrack;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class MoveTrackDownAction extends Action{
    public static final String NAME = "MOVE_TRACK_DOWN";
    
    public MoveTrackDownAction(TablatureEditor tablatureEditor) {
        super(NAME,false,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
        UndoableMoveTrackDown undoable = UndoableMoveTrackDown.startUndo(); 
    	
        Caret caret = getEditor().getTablature().getCaret();        
        SongTrack track = caret.getSongTrackCoords().getTrack();
       
        if(getSongManager().moveTrackDown(track)){
        	updateTablature();
        	TuxGuitar.instance().getMixer().update();	
        	redraw();    
	    
        	//termia el undoable
        	getEditor().getUndoManager().addEdit(undoable.endUndo(track)); 
        }
	    return true;
    }

}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/track/MoveTrackDownAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.track;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.editors.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.track.UndoableMoveTrackDown;
import org.herac.tuxguitar.song.models.SongTrack;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class MoveTrackDownAction extends Action{
    public static final String NAME = "action.track.move-down";
    
    public MoveTrackDownAction(TablatureEditor tablatureEditor) {
        super(NAME,false,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
        UndoableMoveTrackDown undoable = UndoableMoveTrackDown.startUndo(); 
    	
        Caret caret = getEditor().getTablature().getCaret();        
        SongTrack track = caret.getSongTrackCoords().getTrack();
       
        if(getSongManager().moveTrackDown(track)){
        	updateTablature();
        	TuxGuitar.instance().getMixer().update();	
        	redraw();    
	    
        	//termia el undoable
        	getEditor().getUndoManager().addEdit(undoable.endUndo(track)); 
        }
	    return true;
    }

}
